@@ -18,8 +18,8 @@ import pango
 # Global variables
 CURRENT_REMOTETYPE= ""
 TIME2BEEB = "" # Interwall of beebs (if counting up)
-beeb = "/opt/pykake/sounds/bell.wav" # Sound file of beeb
-alert = "/opt/pykake/sounds/drums.wav" # Sound file of alert
+beeb = "file:/opt/pykake/sounds/bell.wav" # Sound file of beeb
+alert = "file:/opt/pykake/sounds/drums.wav" # Sound file of alert
 
 bulbStatus = False  # On/Off told is this first or second time button hitted in bulb
 mod2sec = False # Told Canon (in bulbmode) should it use 2sec delay or not
